@@ -107,3 +107,9 @@ Exponential$set("public","initialize",function(rate = 1, scale = NULL, decorator
                    variateForm = "univariate")
   invisible(self)
 })
+
+.distr6$distributions = rbind(.distr6$distributions,
+                              data.table::data.table(ShortName = "Exp", ClassName = "Exponential",
+                                                     Type = "\u211D+", ValueSupport = "continuous",
+                                                     VariateForm = "univariate",
+                                                     Package = "stats"))
