@@ -144,3 +144,10 @@ Pareto$set("public","initialize",function(shape = 1, scale = 1, decorators = NUL
                    variateForm = "univariate")
   invisible(self)
 })
+
+.distr6$distributions = rbind(.distr6$distributions,
+                              data.table::data.table(ShortName = "Pare", ClassName = "Pareto",
+                                                     Type = "\u211D+", ValueSupport = "continuous",
+                                                     VariateForm = "univariate",
+                                                     Package = "distr6"))
+
